@@ -4,6 +4,7 @@ use v5.24;
 use warnings;
 use experimental 'signatures';
 
+use File::Spec::Unix ();
 use Archive::Tar ();
 use Archive::Tar::Constant ();
 
@@ -85,7 +86,8 @@ sub _child ($self, $key, $type) {
 sub get_asset ($self, $key) {
    my $child = $self->_child($key, Archive::Tar::Constant::FILE)
       or $self->not_found($key);
-   return $self->asset($key => raw => $child->get_content);
+   my (undef, undef, $basename) = File::Spec::Unix->splitpath($key);
+   return $self->asset($basename => raw => $child->get_content);
 }
 
 sub get_sub_resolver ($self, $key) {
